@@ -45,6 +45,7 @@ tar_files <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = c("file", "url", "aws_file"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
@@ -66,6 +67,7 @@ tar_files <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
