@@ -164,3 +164,59 @@ targets::tar_test("hook invalidates target", {
   expect_equal(out$name, "a")
   expect_equal(out$progress, "built")
 })
+
+targets::tar_test("tar_hook_before() sets deps by default", {
+  x <- targets::tar_target(x1, task1())
+  y <- tar_hook_before(x, f())[[1]]
+  expect_true("task1" %in% y$command$deps)
+  expect_true("f" %in% y$command$deps)
+})
+
+targets::tar_test("tar_hook_before() sets_deps = FALSE", {
+  x <- targets::tar_target(x1, task1())
+  y <- tar_hook_before(x, f(), set_deps = FALSE)[[1]]
+  expect_true("task1" %in% y$command$deps)
+  expect_false("f" %in% y$command$deps)
+})
+
+targets::tar_test("tar_hook_before(), set_deps = TRUE, deps arg", {
+  targets::tar_script({
+    tar_hook_before(
+    targets = list(
+      targets::tar_target_raw("upstream1", "I am upstream 1 running"),
+      targets::tar_target_raw("upstream2", "I am upstream 2 running"),
+      targets::tar_target_raw(
+        name = "downstream",
+        command = "I am downstream running",
+        deps = c("upstream1", "upstream2")
+      )
+    ),
+    hook = message("Running hook."),
+    set_deps = TRUE
+  )
+  })
+  edges <- targets::tar_network(callr_function = NULL)$edges
+  expect_equal(nrow(edges), 0L)
+})
+
+targets::tar_test("tar_hook_before(), set_deps = FALSE, deps arg", {
+  targets::tar_script({
+    tar_hook_before(
+    targets = list(
+      targets::tar_target_raw("upstream1", "I am upstream 1 running"),
+      targets::tar_target_raw("upstream2", "I am upstream 2 running"),
+      targets::tar_target_raw(
+        name = "downstream",
+        command = "I am downstream running",
+        deps = c("upstream1", "upstream2")
+      )
+    ),
+    hook = message("Running hook."),
+    set_deps = FALSE
+  )
+  })
+  edges <- targets::tar_network(callr_function = NULL)$edges
+  expect_equal(nrow(edges), 2L)
+  expect_equal(edges$to, rep("downstream", 2L))
+  expect_equal(sort(edges$from), sort(c("upstream1", "upstream2")))
+})
